@@ -1,5 +1,3 @@
-from __future__ import division, print_function, absolute_import
-
 __usage__ = """
 To run tests locally:
   python tests/test_arpack.py [-l<int>] [-v<int>]
@@ -12,7 +10,7 @@ import itertools
 import numpy as np
 
 from numpy.testing import (assert_allclose, assert_array_almost_equal_nulp,
-                           assert_equal, assert_array_equal)
+                           assert_equal, assert_array_equal, suppress_warnings)
 from pytest import raises as assert_raises
 import pytest
 
@@ -24,7 +22,6 @@ from scipy.sparse.linalg.eigen.arpack import eigs, eigsh, svds, \
      ArpackNoConvergence, arpack
 
 from scipy._lib._gcutils import assert_deallocated, IS_PYPY
-from scipy._lib._numpy_compat import suppress_warnings
 
 
 # precision for tests
